mafw.processor\_library.importer
================================

.. automodule:: mafw.processor_library.importer

   
   .. rubric:: Classes

   .. autosummary::
   
      FilenameElement
      FilenameParser
      Importer
   